@@ -10,7 +10,7 @@ our @ISA         = qw(Exporter);
 our %EXPORT_TAGS = ( all => [ qw(slurp_xml) ] );
 our @EXPORT_OK   = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT      = qw();
-our $VERSION     = '0.59';
+our $VERSION     = '0.60';
 
 my $use_module;
 
@@ -140,6 +140,11 @@ sub new {
     else {
         if ($_[0] =~ m{\A https?:}xms) {
             require Acme::HTTP;
+            Acme::HTTP->import(qw(:all));
+
+            set_timeout(10);
+            set_redir_max(5);
+
             $fh = Acme::HTTP->new($_[0])
               or croak "Failed assertion #0042 in XML::Reader->new: Can't Acme::HTTP->new('$_[0]') because $@";
         }
@@ -763,18 +768,11 @@ sub get_token {
     my $self = shift;
 
     until (@{$self->NB_data}) {
-
         # Here is the all important reading of a chunk of XML-data from the filehandle...
 
         my $buf;
 
-        if (ref($self->NB_fh) eq 'Net::HTTP::NB' or ref($self->NB_fh) eq 'Net::HTTPS::NB') {
-            use IO::Select;
-            my $sel = IO::Select->new($self->NB_fh);
-
-            # we allow 15 seconds before timeout
-            croak "Failed assertion #0062 in subroutine XML::Reader->get_token: timeout 15 seconds" unless $sel->can_read(15);
-
+        if (ref($self->NB_fh) eq 'Acme::HTTP') {
             my $ct = $self->NB_fh->read_entity_body($buf, 4096); # returns number of bytes read, or undef if IO-Error
             last unless $ct;
         }
@@ -1003,7 +1001,7 @@ sub slurp_xml {
 
 package XML::Reader::Token;
 
-our $VERSION = '0.59';
+our $VERSION = '0.60';
 
 sub found_start_tag   { $_[0][0] eq '<'; }
 sub found_end_tag     { $_[0][0] eq '>'; }
